part of 'org_types_bloc.dart';

abstract class OrgTypesState extends Equatable {
  const OrgTypesState();
  @override
  List<Object?> get props => [];
}

class OrgTypesInitial extends OrgTypesState {
  const OrgTypesInitial();
}

class OrgTypesLoading extends OrgTypesState {
  const OrgTypesLoading();
}

class OrgTypesLoaded extends OrgTypesState {
  final List<TypeReferenceEntity> types;
  const OrgTypesLoaded(this.types);
  @override
  List<Object?> get props => [types];
}

class OrgTypesError extends OrgTypesState {
  final String message;
  const OrgTypesError(this.message);
  @override
  List<Object?> get props => [message];
}

class OrgTypeOperating extends OrgTypesState {
  final List<TypeReferenceEntity> types;
  const OrgTypeOperating(this.types);
  @override
  List<Object?> get props => [types];
}

class OrgTypeSuccess extends OrgTypesState {
  final List<TypeReferenceEntity> types;
  final String message;
  const OrgTypeSuccess({required this.types, required this.message});
  @override
  List<Object?> get props => [types, message];
}

class OrgTypeOperationError extends OrgTypesState {
  final List<TypeReferenceEntity> types;
  final String message;
  const OrgTypeOperationError({required this.types, required this.message});
  @override
  List<Object?> get props => [types, message];
}
